summaryrefslogtreecommitdiffstats
path: root/lib/interfaces/kdevmainwindow.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/interfaces/kdevmainwindow.h')
-rw-r--r--lib/interfaces/kdevmainwindow.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/interfaces/kdevmainwindow.h b/lib/interfaces/kdevmainwindow.h
index 27f63273..1a2ea9b6 100644
--- a/lib/interfaces/kdevmainwindow.h
+++ b/lib/interfaces/kdevmainwindow.h
@@ -26,7 +26,7 @@
class TQWidget;
class KStatusBar;
-class KMainWindow;
+class TDEMainWindow;
/**
@file kdevmainwindow.h
@@ -91,8 +91,8 @@ public:
@param caption the caption to set.*/
virtual void setCurrentDocumentCaption( const TQString &caption ) = 0;
- /**@return KMainWindow object which actually represents the main window.*/
- virtual KMainWindow *main() = 0;
+ /**@return TDEMainWindow object which actually represents the main window.*/
+ virtual TDEMainWindow *main() = 0;
/**@return KStatusBar object which actually represents the status bar in the main window.*/
KStatusBar *statusBar();